from PyObjCTools.TestSupport import TestCase, min_os_level

import ClassKit
import objc


class TestCLSDataStore(TestCase):
    def test_protocols(self):
        objc.protocolNamed("CLSDataStoreDelegate")

    def test_methods(self):
        self.assertArgIsBlock(ClassKit.CLSDataStore.saveWithCompletion_, 0, b"v@")
        self.assertArgIsBlock(
            ClassKit.CLSDataStore.contextsMatchingIdentifierPath_completion_, 1, b"v@@"
        )

    @min_os_level("11.3")
    def test_methods11_3(self):
        self.assertArgIsBlock(
            ClassKit.CLSDataStore.fetchActivityForURL_completion_, 1, b"v@@"
        )



from PyObjCTools.TestSupport import TestCase

import ClassKit  # noqa: F401
import objc


class TestCLSActivityHelper(ClassKit.NSObject):
    def updateDescendantsOfContext_completion_(self, a, b):
        pass


class TestCLSActivity(TestCase):
    def test_protocols(self):
        objc.protocolNamed("CLSContextProvider")

    def test_methods(self):
        self.assertArgIsBlock(
            TestCLSActivityHelper.updateDescendantsOfContext_completion_, 1, b"v@"
        )



from PyObjCTools.TestSupport import TestCase, min_os_level

import ClassKit


class TestCLSContext(TestCase):
    def test_constants(self):
        self.assertEqual(ClassKit.CLSContextTypeNone, 0)
        self.assertEqual(ClassKit.CLSContextTypeApp, 1)
        self.assertEqual(ClassKit.CLSContextTypeChapter, 2)
        self.assertEqual(ClassKit.CLSContextTypeSection, 3)
        self.assertEqual(ClassKit.CLSContextTypeLevel, 4)
        self.assertEqual(ClassKit.CLSContextTypePage, 5)
        self.assertEqual(ClassKit.CLSContextTypeTask, 6)
        self.assertEqual(ClassKit.CLSContextTypeChallenge, 7)
        self.assertEqual(ClassKit.CLSContextTypeQuiz, 8)
        self.assertEqual(ClassKit.CLSContextTypeExercise, 9)
        self.assertEqual(ClassKit.CLSContextTypeLesson, 10)
        self.assertEqual(ClassKit.CLSContextTypeBook, 11)
        self.assertEqual(ClassKit.CLSContextTypeGame, 12)
        self.assertEqual(ClassKit.CLSContextTypeDocument, 13)
        self.assertEqual(ClassKit.CLSContextTypeAudio, 14)
        self.assertEqual(ClassKit.CLSContextTypeVideo, 15)
        self.assertEqual(ClassKit.CLSContextTypeCourse, 16)
        self.assertEqual(ClassKit.CLSContextTypeCustom, 17)

    @min_os_level("10.16")
    def test_constants10_16(self):
        self.assertIsInstance(ClassKit.CLSContextTopicMath, str)
        self.assertIsInstance(ClassKit.CLSContextTopicScience, str)
        self.assertIsInstance(ClassKit.CLSContextTopicLiteracyAndWriting, str)
        self.assertIsInstance(ClassKit.CLSContextTopicWorldLanguage, str)
        self.assertIsInstance(ClassKit.CLSContextTopicSocialScience, str)
        self.assertIsInstance(
            ClassKit.CLSContextTopicComputerScienceAndEngineering, str
        )
        self.assertIsInstance(ClassKit.CLSContextTopicArtsAndMusic, str)
        self.assertIsInstance(ClassKit.CLSContextTopicHealthAndFitness, str)

    def test_methods(self):
        self.assertResultIsBOOL(ClassKit.CLSContext.isAssignable)
        self.assertArgIsBOOL(ClassKit.CLSContext.setAssignable_, 0)
        self.assertResultIsBOOL(ClassKit.CLSContext.isActive)

        self.assertArgIsBlock(
            ClassKit.CLSContext.descendantMatchingIdentifierPath_completion_, 1, b"v@@"
        )



from PyObjCTools.TestSupport import TestCase

import ClassKit


class TestCLSProgressReportingCapability(TestCase):
    def test_constants(self):
        self.assertEqual(ClassKit.CLSProgressReportingCapabilityKindDuration, 0)
        self.assertEqual(ClassKit.CLSProgressReportingCapabilityKindPercent, 1)
        self.assertEqual(ClassKit.CLSProgressReportingCapabilityKindBinary, 2)
        self.assertEqual(ClassKit.CLSProgressReportingCapabilityKindQuantity, 3)
        self.assertEqual(ClassKit.CLSProgressReportingCapabilityKindScore, 4)



# This file is generated by objective.metadata
#
# Last update: Thu Apr  8 12:15:52 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$CLSContextTopicArtsAndMusic$CLSContextTopicComputerScienceAndEngineering$CLSContextTopicHealthAndFitness$CLSContextTopicLiteracyAndWriting$CLSContextTopicMath$CLSContextTopicScience$CLSContextTopicSocialScience$CLSContextTopicWorldLanguage$CLSErrorCodeDomain$CLSErrorObjectKey$CLSErrorUnderlyingErrorsKey$CLSPredicateKeyPathDateCreated$CLSPredicateKeyPathIdentifier$CLSPredicateKeyPathParent$CLSPredicateKeyPathTitle$CLSPredicateKeyPathTopic$CLSPredicateKeyPathUniversalLinkURL$"""
enums = """$CLSBinaryValueTypeCorrectIncorrect@3$CLSBinaryValueTypePassFail@1$CLSBinaryValueTypeTrueFalse@0$CLSBinaryValueTypeYesNo@2$CLSContextTypeApp@1$CLSContextTypeAudio@14$CLSContextTypeBook@11$CLSContextTypeChallenge@7$CLSContextTypeChapter@2$CLSContextTypeCourse@16$CLSContextTypeCustom@17$CLSContextTypeDocument@13$CLSContextTypeExercise@9$CLSContextTypeGame@12$CLSContextTypeLesson@10$CLSContextTypeLevel@4$CLSContextTypeNone@0$CLSContextTypePage@5$CLSContextTypeQuiz@8$CLSContextTypeSection@3$CLSContextTypeTask@6$CLSContextTypeVideo@15$CLSErrorCodeAuthorizationDenied@4$CLSErrorCodeClassKitUnavailable@1$CLSErrorCodeDatabaseInaccessible@5$CLSErrorCodeInvalidArgument@2$CLSErrorCodeInvalidCreate@7$CLSErrorCodeInvalidModification@3$CLSErrorCodeInvalidUpdate@8$CLSErrorCodeLimits@6$CLSErrorCodeNone@0$CLSErrorCodePartialFailure@9$CLSProgressReportingCapabilityKindBinary@2$CLSProgressReportingCapabilityKindDuration@0$CLSProgressReportingCapabilityKindPercent@1$CLSProgressReportingCapabilityKindQuantity@3$CLSProgressReportingCapabilityKindScore@4$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"CLSActivity",
        b"contextsMatchingPredicate:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"CLSActivity", b"isStarted", {"retval": {"type": b"Z"}})
    r(b"CLSBinaryItem", b"setValue:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CLSBinaryItem", b"value", {"retval": {"type": b"Z"}})
    r(
        b"CLSContext",
        b"descendantMatchingIdentifierPath:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(b"CLSContext", b"isActive", {"retval": {"type": b"Z"}})
    r(b"CLSContext", b"isAssignable", {"retval": {"type": b"Z"}})
    r(b"CLSContext", b"setAssignable:", {"arguments": {2: {"type": b"Z"}}})
    r(
        b"CLSDataStore",
        b"contextsMatchingIdentifierPath:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CLSDataStore",
        b"fetchActivityForURL:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"CLSDataStore",
        b"saveWithCompletion:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"NSObject",
        b"createContextForIdentifier:parentContext:parentIdentifierPath:",
        {
            "required": True,
            "retval": {"type": b"@"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"updateDescendantsOfContext:completion:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    },
                    "type": b"@?",
                },
            },
        },
    )
    r(b"NSUserActivity", b"isClassKitDeepLink", {"retval": {"type": b"Z"}})
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase

import ClassKit


class TestCLSDeeplinks(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(ClassKit.NSUserActivity.isClassKitDeepLink)



"""
Python mapping for the ClassKit framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from ClassKit import _metadata
from ClassKit import _ClassKit

sys.modules["ClassKit"] = mod = objc.ObjCLazyModule(
    "ClassKit",
    "com.apple.ClassKit",
    objc.pathForFramework("/System/Library/Frameworks/ClassKit.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_ClassKit, Foundation),
)


del sys.modules["ClassKit._metadata"]



from PyObjCTools.TestSupport import TestCase

import ClassKit


class TestCLSBinaryItem(TestCase):
    def test_constants(self):
        self.assertEqual(ClassKit.CLSBinaryValueTypeTrueFalse, 0)
        self.assertEqual(ClassKit.CLSBinaryValueTypePassFail, 1)
        self.assertEqual(ClassKit.CLSBinaryValueTypeYesNo, 2)
        self.assertEqual(ClassKit.CLSBinaryValueTypeCorrectIncorrect, 3)

    def test_methods(self):
        self.assertResultIsBOOL(ClassKit.CLSBinaryItem.value)
        self.assertArgIsBOOL(ClassKit.CLSBinaryItem.setValue_, 0)



from PyObjCTools.TestSupport import TestCase, min_os_level

import ClassKit


class TestCLSActivity(TestCase):
    def test_constants(self):
        self.assertEqual(ClassKit.CLSErrorCodeNone, 0)
        self.assertEqual(ClassKit.CLSErrorCodeClassKitUnavailable, 1)
        self.assertEqual(ClassKit.CLSErrorCodeInvalidArgument, 2)
        self.assertEqual(ClassKit.CLSErrorCodeInvalidModification, 3)
        self.assertEqual(ClassKit.CLSErrorCodeAuthorizationDenied, 4)
        self.assertEqual(ClassKit.CLSErrorCodeDatabaseInaccessible, 5)
        self.assertEqual(ClassKit.CLSErrorCodeLimits, 6)
        self.assertEqual(ClassKit.CLSErrorCodeInvalidCreate, 7)
        self.assertEqual(ClassKit.CLSErrorCodeInvalidUpdate, 8)
        self.assertEqual(ClassKit.CLSErrorCodePartialFailure, 9)

    @min_os_level("10.16")
    def test_constants10_16(self):
        self.assertIsInstance(ClassKit.CLSErrorObjectKey, str)
        self.assertIsInstance(ClassKit.CLSErrorUnderlyingErrorsKey, str)

        self.assertIsInstance(ClassKit.CLSPredicateKeyPathDateCreated, str)
        self.assertIsInstance(ClassKit.CLSPredicateKeyPathIdentifier, str)
        self.assertIsInstance(ClassKit.CLSPredicateKeyPathTitle, str)
        self.assertIsInstance(ClassKit.CLSPredicateKeyPathUniversalLinkURL, str)
        self.assertIsInstance(ClassKit.CLSPredicateKeyPathTopic, str)
        self.assertIsInstance(ClassKit.CLSPredicateKeyPathParent, str)
